@@ -1,6 +1,6 @@
 from .thing import Thing, Platform, Vessel, Sensor, Component
 from .thing import TimeSeries, FlagTimeSeries, GPSTrack
-from .get_data import token2header, PyNIVAError
+from .get_data import token2header, PyNIVAError, get_newly_inserted_data
 from .tsb import TSB_HOST, PUB_TSB
 from .metaflow import META_HOST, PUB_META
 
@@ -8,4 +8,4 @@ __all__ = ["Thing", "Platform", "Vessel", "Sensor", "TimeSeries",
            "Component", 
            "FlagTimeSeries", "GPSTrack", "token2header",
            "META_HOST", "TSB_HOST", 
-           "PUB_META", "PUB_TSB", "PyNIVAError"]
\ No newline at end of file
+           "PUB_META", "PUB_TSB", "PyNIVAError", "get_newly_inserted_data"]
